@@ -3,7 +3,6 @@
 #         KU Leuven
 # ----------------------
 
-## for testing purposes
 fastLasso <- function(x, y, lambda, subset = NULL, intercept = TRUE, 
         eps = .Machine$double.eps, use.Gram = TRUE) {
     # initializations
@@ -16,7 +15,11 @@ fastLasso <- function(x, y, lambda, subset = NULL, intercept = TRUE,
     }
     # call C++ function
     callBackend <- getBackend()
-    callBackend("R_fastLasso", R_x=x, R_y=y, R_lambda=lambda, 
+    fit <- callBackend("R_fastLasso", R_x=x, R_y=y, R_lambda=lambda, 
         R_useSubset=useSubset, R_subset=subset, R_intercept=isTRUE(intercept), 
         R_eps=eps, R_useGram=isTRUE(use.Gram))
+    fit$coefficients <- drop(fit$coefficients)
+    fit$fitted.values <- drop(fit$fitted.values)
+    fit$residuals <- drop(fit$residuals)
+    fit
 }
